@@ -85,7 +85,7 @@ class Describer(Visitor):
 
     def visit_tuple(self, tup, indent=0):
         indent_str = "  " * indent
-        for value in tup:
+        for value in tup.elements:
             yield from self.describe_node(
                 value, prefix=f"{indent_str}- ", indent=indent + 1,
             )
